==> haskell-lifted-base-0.2.3.12-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.12
id: lifted-base-0.2.3.12-AptnLlCSRcTHtTYEKD9GFf
key: lifted-base-0.2.3.12-AptnLlCSRcTHtTYEKD9GFf
license: BSD-3-Clause
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
abi: 76924329bbd438d5344ec6130dd29184
exposed: True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
import-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-base-0.2.3.12
library-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lifted-base-0.2.3.12
hs-libraries: HSlifted-base-0.2.3.12-AptnLlCSRcTHtTYEKD9GFf
includes:
    inlinable.h
depends:
    base-4.12.0.0 monad-control-1.0.2.3-EQU08Q5uVAI5Qyu4idMrsU
    transformers-base-0.4.5.2-LMjNLq6jsSj2JdftiUxIvR
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.12-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.12
id: lifted-base-0.2.3.12-B68iwk5BNXFLXLdjdYGHmp
key: lifted-base-0.2.3.12-B68iwk5BNXFLXLdjdYGHmp
license: BSD-3-Clause
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
abi: 8330f044424415ce2190501c187e0f49
exposed: True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
import-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-base-0.2.3.12
library-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lifted-base-0.2.3.12
hs-libraries: HSlifted-base-0.2.3.12-B68iwk5BNXFLXLdjdYGHmp
includes:
    inlinable.h
depends:
    base-4.12.0.0 monad-control-1.0.2.3-EKrTS47Oi8IKd1pTyskzd3
    transformers-base-0.4.5.2-KWttVZ7nb0vsLFTQBq79t
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
